@@ -5,11 +5,11 @@ import logging
 from concurrent.futures import ThreadPoolExecutor
 
 import pandas as pd
+from rich.progress import Progress
 
 from .config import settings
 from .db import get_DB_client
 from .save import get_save_client
-from .utils import Progress
 
 logger = logging.getLogger(__name__)
 
@@ -20,6 +20,9 @@ class Collect:
         self.db = get_DB_client(settings.dbm)
 
     async def run(self, classes):
+        if isinstance(classes, str):
+            classes = [row for row in self.get_rows(level="CLASSES", sql=classes)]
+
         loop = asyncio.get_event_loop()
         executor = ThreadPoolExecutor(200)
         with Progress() as p:
@@ -47,7 +50,7 @@ class Collect:
                 loop.run_in_executor(
                     executor, functools.partial(self.parallel_docs, doc, cdclass),
                 )
-                for doc in self.get_keys(cdclass)
+                for doc in self.get_rows(cdclass)
             ]
         )
         loop.run_until_complete(parallel_docs)
@@ -56,7 +59,10 @@ class Collect:
 
     def parallel_docs(self, doc, cdclass):
         logger.info(f"Getting key {doc} in class {cdclass}")
-        self.get_objects(doc, cdclass)
+        if doc:
+            self.get_objects(doc, cdclass)
+        else:
+            logger.error(f"Empty key in class {cdclass}, it will be ignored")
 
     def get_objects(self, key, cdclass):
         if self.sh.check_obj(cdclass, key):
@@ -70,13 +76,17 @@ class Collect:
             except AttributeError:
                 logger.error(f"The key {key} has a empty file, it will be ignored")
 
-    def get_keys(self, cdclass):
-        exists, docs = self.sh.check_meta(f"DOCS_LIST_{cdclass}")
+    def get_rows(self, cdclass=None, level="DOCS", sql=settings.keys_sql):
+        if not cdclass:
+            cdclass = sql
+        exists, docs = self.sh.check_meta(f"{level}_LIST_{cdclass}")
         if exists:
-            logger.info("List of keys for class {cdclass} already exists")
+            logger.info(f"List of rows for {cdclass} already exists")
+            docs.dropna(inplace=True)
             yield from [doc[0] for _, doc in docs.iterrows()]
         else:
-            docs = self.db.get_keys(cdclass)
-            docs = [doc[0] for doc in docs]
-            self.sh.save_meta(pd.DataFrame(docs), f"DOCS_LIST_{cdclass}")
-            yield from docs
+            rows = self.db.get_rows(sql, format={"CLASSE": cdclass})
+            rows = [row[0] for row in rows]
+            df = pd.DataFrame(rows).dropna()
+            self.sh.save_meta(df, f"{level}_LIST_{cdclass}")
+            yield from rows
