@@ -107,10 +107,13 @@ def collect(settings, secrets, save, classes):
     if not classes:
         logger.info("Loading classes from settings")
         classes = s.classes
-    classes_list = list(pd.read_csv(classes, header=None).iloc[:, 0])
-    logger.info(f"Found {len(classes_list)} classes")
+    if ".sql" not in classes:
+        classes = list(pd.read_csv(classes, header=None).iloc[:, 0])
+        logger.info(f"Found {len(classes)} classes")
+    else:
+        logger.info("Received a SQL for getting the classes")
     loop = asyncio.get_event_loop()
-    loop.run_until_complete(c.run(classes_list))
+    loop.run_until_complete(c.run(classes))
     logger.info("Successful collect command")
 
 
