@@ -32,9 +32,9 @@ class Abstract_DB(ABC):
     def fetch_all(self, sql):
         pass
 
-    def get_keys(self, cdclass):
-        logger.info(f"Getting keys for class {cdclass}")
-        sql = get_sql(settings.keys_sql).format(CLASSE=cdclass)
+    def get_rows(self, query, format):
+        logger.info(f"Getting rows {format}")
+        sql = get_sql(query).format(**format)
         return self.fetch_all(sql)
 
     def get_objects(self, key):
