@@ -25,13 +25,13 @@ class Query:
         logger.info("Running query")
         with elapsed_time as et:
             task = et.add_task("Running your query, elapsed time:")
-            result = self.db.fetch_all(query)
+            cnxn = self.db.set_up_connection()
+            df = pd.read_sql(query, cnxn)
             et.stop_task(task)
 
         logger.info("Finished running query")
-        df = pd.DataFrame(result)
 
         print_table(df.head(50), "Your query first 50 results")
-
+        print(f"Saving result to {filename}")
         logger.info(f"Saving result to {filename}")
         self.sh.save_meta(df, filename)
