@@ -18,12 +18,11 @@ class S3SaveHandler(AbstractSaveHandler):
         proxy = settings.get("proxy", None)
         if proxy:
             logger.info(f"Using proxy for S3 connection. Proxy: {settings.proxy}")
-        sess = Session(
-            settings.access_key,
-            settings.secret_access_key,
+        sess = Session(settings.access_key, settings.secret_access_key,)
+        self.s3 = sess.s3(
+            settings.bucket,
             config=botocore.client.Config(proxies=proxy, max_pool_connections=1000),
         )
-        self.s3 = sess.s3(settings.bucket)
 
     def write_file(self, dirname, filename, obj):
         key = dirname + filename
